Stan Math Library: stan/math/prim/mat/fun/minus.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
minus.hpp File Reference

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::minus (const T &x)
| Returns the negation of the specified scalar or matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.